@@ -13,8 +13,6 @@
 import atexit
 import contextlib
 
-import netaddr
-
 from neutron_lib import exceptions as n_exc
 from oslo_log import log
 from ovsdbapp.backend import ovs_idl
@@ -29,11 +27,11 @@ import tenacity
 
 from ovn_octavia_provider.common import config
 from ovn_octavia_provider.common import exceptions as ovn_exc
+from ovn_octavia_provider.common import utils
 from ovn_octavia_provider.i18n import _
 from ovn_octavia_provider.ovsdb import impl_idl_ovn
 from ovn_octavia_provider.ovsdb import ovsdb_monitor
 
-config.register_opts()
 
 LOG = log.getLogger(__name__)
 
@@ -139,35 +137,6 @@ class GetLrsCommand(command.ReadOnlyCommand):
             self.api.tables['Logical_Router'].rows.values()]
 
 
-class LbAddIpPortMappingCommand(command.BaseCommand):
-    table = 'Load_Balancer'
-
-    def __init__(self, api, lb, endpoint_ip, port_name, source_ip):
-        super().__init__(api)
-        self.lb = lb
-        self.endpoint_ip = str(netaddr.IPAddress(endpoint_ip))
-        self.port_name = port_name
-        self.source_ip = str(netaddr.IPAddress(source_ip))
-
-    def run_idl(self, txn):
-        lb = self.api.lookup(self.table, self.lb)
-        lb.setkey('ip_port_mappings', self.endpoint_ip,
-                  '%s:%s' % (self.port_name, self.source_ip))
-
-
-class LbDelIpPortMappingCommand(command.BaseCommand):
-    table = 'Load_Balancer'
-
-    def __init__(self, api, lb, endpoint_ip):
-        super().__init__(api)
-        self.lb = lb
-        self.endpoint_ip = str(netaddr.IPAddress(endpoint_ip))
-
-    def run_idl(self, txn):
-        lb = self.api.lookup(self.table, self.lb)
-        lb.delkey('ip_port_mappings', self.endpoint_ip)
-
-
 class OvsdbNbOvnIdl(nb_impl_idl.OvnNbApiIdlImpl, Backend):
     def __init__(self, connection):
         super().__init__(connection)
@@ -203,21 +172,6 @@ class OvsdbNbOvnIdl(nb_impl_idl.OvnNbApiIdlImpl, Backend):
     def get_lrs(self):
         return GetLrsCommand(self)
 
-    # FIXME (froyo): Remove this method once the ovsdbapp version is upgraded
-    # to a version higher than 2.1.0, it will be possible to remove this method
-    # This is done due to some conflict on bumping the noted version. Also
-    # class LbDelIpPortMappingCommand shall be removed at the same time.
-    def lb_del_ip_port_mapping(self, lb, endpoint_ip):
-        return LbDelIpPortMappingCommand(self, lb, endpoint_ip)
-
-    # FIXME (froyo): Remove this method once the ovsdbapp version is upgraded
-    # to a version higher than 2.1.0, it will be possible to remove this method
-    # This is done due to some conflict on bumping the noted version. Also
-    # class LbAddIpPortMappingCommand shall be removed at the same time.
-    def lb_add_ip_port_mapping(self, lb, endpoint_ip, port_name, source_ip):
-        return LbAddIpPortMappingCommand(self, lb, endpoint_ip, port_name,
-                                         source_ip)
-
 
 class OvsdbSbOvnIdl(sb_impl_idl.OvnSbApiIdlImpl, Backend):
     def __init__(self, connection):
@@ -245,10 +199,7 @@ class OvnNbIdlForLb(ovsdb_monitor.OvnIdl):
             self.set_lock(self.event_lock_name)
         atexit.register(self.stop)
 
-    @tenacity.retry(
-        wait=tenacity.wait_exponential(
-            max=config.get_ovn_ovsdb_retry_max_interval()),
-        reraise=True)
+    @utils.retry()
     def _get_ovsdb_helper(self, connection_string):
         return idlutils.get_schema_helper(connection_string, self.SCHEMA)
 
@@ -287,10 +238,7 @@ class OvnSbIdlForLb(ovsdb_monitor.OvnIdl):
             self.set_lock(self.event_lock_name)
         atexit.register(self.stop)
 
-    @tenacity.retry(
-        wait=tenacity.wait_exponential(
-            max=config.get_ovn_ovsdb_retry_max_interval()),
-        reraise=True)
+    @utils.retry()
     def _get_ovsdb_helper(self, connection_string):
         return idlutils.get_schema_helper(connection_string, self.SCHEMA)
 
